![Routemaster](docs/logo-readme-github.png)

- - -

[![CircleCI](https://circleci.com/gh/thread/routemaster.svg?style=shield&circle-token=3973777302b4f7f00f5b9eb1c07e3c681ea94f35)](https://circleci.com/gh/thread/routemaster) [![Coverage Status](https://coveralls.io/repos/github/thread/routemaster/badge.svg?branch=master)](https://coveralls.io/github/thread/routemaster?branch=master)

State machines as a service.

Routemaster is designed to enable the creation of complex, but clearly defined,
state machines used by multiple separate services.


##### Useful Links

 - [About Routemaster](docs/about.md)
 - [Glossary](docs/glossary.md)
 - [Hacking on Routemaster](docs/hacking.md)
 - [Deployment](docs/deployment.md)
 - [Migrations FAQ](docs/migrations.md)
 - [Routemaster on PyPI](https://pypi.python.org/pypi/routemaster)
 - [Routemaster on Docker Hub](https://hub.docker.com/r/thread/routemaster/)
